@@ -1,5 +1,5 @@
 // goredo -- djb's redo implementation on pure Go
-// Copyright (C) 2020-2024 Sergey Matveev <stargrave@stargrave.org>
+// Copyright (C) 2020-2025 Sergey Matveev <stargrave@stargrave.org>
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -78,14 +78,14 @@ func (ifchange *Ifchange) Hash() Hash {
 }
 
 type Dep struct {
-	build     uuid.UUID
-	always    bool
-	stamp     Hash
 	ifcreates []*Tgt
 	ifchanges []*Ifchange
+	stamp     Hash
+	build     uuid.UUID
+	always    bool
 }
 
-func ifcreate(w io.Writer, fdDepName string, tgt string) (err error) {
+func ifcreate(w io.Writer, fdDepName, tgt string) (err error) {
 	tracef(CDebug, "ifcreate: %s <- %s", fdDepName, tgt)
 	_, err = io.Copy(w, bytes.NewBuffer(chunkWrite(append(
 		[]byte{DepTypeIfcreate}, []byte(tgt)...,
@@ -104,7 +104,7 @@ func always(w io.Writer, fdDepName string) (err error) {
 func stamp(w io.Writer, fdDepName string, hsh Hash) (err error) {
 	tracef(CDebug, "stamp: %s <- %s", fdDepName, hsh)
 	_, err = io.Copy(w, bytes.NewBuffer(chunkWrite(append(
-		[]byte{DepTypeStamp}, []byte(hsh)...,
+		[]byte{DepTypeStamp}, hsh[:]...,
 	))))
 	return
 }
@@ -112,7 +112,7 @@ func stamp(w io.Writer, fdDepName string, hsh Hash) (err error) {
 func fileHash(fd io.Reader) (Hash, error) {
 	h := blake3.New(HashLen, nil)
 	if _, err := io.Copy(h, bufio.NewReader(fd)); err != nil {
-		return "", err
+		return HashNull, err
 	}
 	return Hash(h.Sum(nil)), nil
 }
@@ -131,7 +131,7 @@ func depWrite(w io.Writer, fdDepName, cwd string, tgt *Tgt, hsh Hash) (err error
 	if isDir {
 		return nil
 	}
-	if hsh == "" {
+	if hsh == HashNull {
 		hsh, err = fileHash(fd)
 		if err != nil {
 			return ErrLine(err)
@@ -140,7 +140,7 @@ func depWrite(w io.Writer, fdDepName, cwd string, tgt *Tgt, hsh Hash) (err error
 	_, err = io.Copy(w, bytes.NewBuffer(chunkWrite(bytes.Join([][]byte{
 		{DepTypeIfchange},
 		inode[:],
-		[]byte(hsh),
+		hsh[:],
 		[]byte(tgt.RelTo(cwd)),
 	}, nil))))
 	return
@@ -170,7 +170,7 @@ func depsWrite(fdDep *os.File, tgts []*Tgt) error {
 		}
 		tgtDir := path.Join(cwd, DirPrefix)
 		if _, errStat := os.Stat(tgt.a); errStat == nil {
-			err = ErrLine(depWrite(fdDepW, fdDep.Name(), tgtDir, tgt, ""))
+			err = ErrLine(depWrite(fdDepW, fdDep.Name(), tgtDir, tgt, HashNull))
 		} else {
 			tgtRel := tgt.RelTo(tgtDir)
 			err = ErrLine(depWriteNonex(fdDepW, fdDep.Name(), tgtRel))
@@ -203,7 +203,7 @@ func depHeadParse(data []byte) (build uuid.UUID, tail []byte, err error) {
 	return
 }
 
-func chunkRead(data []byte) (typ byte, chunk []byte, tail []byte, err error) {
+func chunkRead(data []byte) (typ byte, chunk, tail []byte, err error) {
 	if len(data) < 2 {
 		err = errors.New("no length")
 		return
