@@ -6,8 +6,10 @@ import (
 
 const HashLen = 32
 
-type Hash string
+type Hash [HashLen]byte
+
+var HashNull Hash
 
 func (h Hash) String() string {
-	return hex.EncodeToString([]byte(h))
+	return hex.EncodeToString(h[:])
 }
