@@ -1,5 +1,5 @@
 // goredo -- djb's redo implementation on pure Go
-// Copyright (C) 2020-2024 Sergey Matveev <stargrave@stargrave.org>
+// Copyright (C) 2020-2025 Sergey Matveev <stargrave@stargrave.org>
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -205,7 +205,7 @@ func ifchange(tgts []*Tgt, forced, traced bool) (bool, error) {
 		close(okChecker)
 	}()
 	for _, tgt := range tgts {
-		if _, ok := seen[tgt.rel]; ok {
+		if _, exists := seen[tgt.rel]; exists {
 			tracef(CDebug, "%s was already build as a dependant", tgt)
 			continue
 		}
