@@ -23,7 +23,7 @@ import (
 	"os"
 	"strconv"
 
-	"go.cypherpunks.su/recfile/v2"
+	"go.cypherpunks.su/recfile/v3"
 	"golang.org/x/sys/unix"
 )
 
@@ -65,25 +65,26 @@ func (our *Inode) Equals(their *Inode) bool {
 
 func (inode *Inode) RecfileFields() []recfile.Field {
 	return []recfile.Field{
-		{Name: "Size", Value: strconv.FormatUint(binary.BigEndian.Uint64(
+		{F: "Size", V: strconv.FormatUint(binary.BigEndian.Uint64(
 			[]byte(inode[0*8:1*8])), 10)},
-		{Name: "InodeNum", Value: strconv.FormatUint(binary.BigEndian.Uint64(
+		{F: "InodeNum", V: strconv.FormatUint(binary.BigEndian.Uint64(
 			[]byte(inode[1*8:2*8])), 10)},
-		{Name: "CtimeSec", Value: strconv.FormatUint(binary.BigEndian.Uint64(
+		{F: "CtimeSec", V: strconv.FormatUint(binary.BigEndian.Uint64(
 			[]byte(inode[2*8:3*8])), 10)},
-		{Name: "CtimeNsec", Value: strconv.FormatUint(binary.BigEndian.Uint64(
+		{F: "CtimeNsec", V: strconv.FormatUint(binary.BigEndian.Uint64(
 			[]byte(inode[3*8:4*8])), 10)},
-		{Name: "MtimeSec", Value: strconv.FormatUint(binary.BigEndian.Uint64(
+		{F: "MtimeSec", V: strconv.FormatUint(binary.BigEndian.Uint64(
 			[]byte(inode[4*8:5*8])), 10)},
-		{Name: "MtimeNsec", Value: strconv.FormatUint(binary.BigEndian.Uint64(
+		{F: "MtimeNsec", V: strconv.FormatUint(binary.BigEndian.Uint64(
 			[]byte(inode[5*8:6*8])), 10)},
 	}
 }
 
 func inodeFromFileStat(fi os.FileInfo, stat unix.Stat_t) *Inode {
 	ctimeSec, ctimeNsec := stat.Ctim.Unix()
-	mtimeSec := fi.ModTime().Unix()
 	mtimeNsec := fi.ModTime().UnixNano()
+	mtimeSec := mtimeNsec / 1000000000
+	mtimeNsec -= mtimeSec * 1000000000
 	inode := new(Inode)
 	binary.BigEndian.PutUint64(inode[0*8:1*8], uint64(fi.Size()))
 	binary.BigEndian.PutUint64(inode[1*8:2*8], uint64(stat.Ino))
