@@ -135,7 +135,7 @@ func stderrWrite(s string) {
 	LogMutex.Unlock()
 }
 
-func tracef(level, format string, args ...interface{}) {
+func tracef(level, format string, args ...any) {
 	var p string
 	if MyPID != 0 {
 		p = fmt.Sprintf("[%d] ", MyPID)
