@@ -34,7 +34,7 @@ import (
 	"syscall"
 
 	"github.com/google/uuid"
-	"go.cypherpunks.su/recfile/v2"
+	"go.cypherpunks.su/recfile/v3"
 	"golang.org/x/sys/unix"
 )
 
@@ -265,7 +265,7 @@ func main() {
 			log.Fatal(err)
 		}
 		OODTgts = make(map[string]struct{})
-		for _, tgtRaw := range bytes.Split(tgtsRaw, []byte{0}) {
+		for tgtRaw := range bytes.SplitSeq(tgtsRaw, []byte{0}) {
 			t := string(tgtRaw)
 			if t == "" {
 				continue
@@ -520,7 +520,7 @@ func main() {
 				break
 			}
 			err = recfileWrite(os.Stdout, append(
-				[]recfile.Field{{Name: "Target", Value: tgt.String()}},
+				[]recfile.Field{{F: "Target", V: tgt.String()}},
 				inode.RecfileFields()...)...)
 			if err != nil {
 				err = ErrLine(err)
@@ -539,9 +539,7 @@ func main() {
 			break
 		}
 		w := bufio.NewWriter(os.Stdout)
-		err = recfileWrite(w, []recfile.Field{
-			{Name: "Build", Value: build.String()},
-		}...)
+		err = recfileWrite(w, []recfile.Field{{F: "Build", V: build.String()}}...)
 		if err != nil {
 			break
 		}
@@ -552,36 +550,34 @@ func main() {
 			typ, chunk, data, _ = chunkRead(data)
 			switch typ {
 			case DepTypeAlways:
-				err = recfileWrite(w, []recfile.Field{
-					{Name: "Type", Value: "always"},
-				}...)
+				err = recfileWrite(w, []recfile.Field{{F: "Type", V: "always"}}...)
 			case DepTypeStamp:
 				err = recfileWrite(w, []recfile.Field{
-					{Name: "Type", Value: "stamp"},
-					{Name: "Hash", Value: hex.EncodeToString(chunk)},
+					{F: "Type", V: "stamp"},
+					{F: "Hash", V: hex.EncodeToString(chunk)},
 				}...)
 			case DepTypeIfcreate:
 				err = recfileWrite(w, []recfile.Field{
-					{Name: "Type", Value: "ifcreate"},
-					{Name: "Target", Value: string(chunk)},
+					{F: "Type", V: "ifcreate"},
+					{F: "Target", V: string(chunk)},
 				}...)
 			case DepTypeIfchange:
 				name := string(chunk[InodeLen+HashLen:])
 				meta := chunk[:InodeLen+HashLen]
 				fields := []recfile.Field{
-					{Name: "Type", Value: "ifchange"},
-					{Name: "Target", Value: name},
+					{F: "Type", V: "ifchange"},
+					{F: "Target", V: name},
 				}
 				fields = append(fields, recfile.Field{
-					Name: "Hash", Value: Hash(meta[InodeLen:]).String(),
+					F: "Hash", V: Hash(meta[InodeLen:]).String(),
 				})
 				inode = Inode(meta[:][:InodeLen])
 				fields = append(fields, inode.RecfileFields()...)
 				err = recfileWrite(w, fields...)
 			case DepTypeIfchangeNonex:
 				err = recfileWrite(w, []recfile.Field{
-					{Name: "Type", Value: "ifchange"},
-					{Name: "Target", Value: string(chunk)},
+					{F: "Type", V: "ifchange"},
+					{F: "Target", V: string(chunk)},
 				}...)
 			}
 			if err != nil {
