@@ -27,6 +27,7 @@ import (
 	"io"
 	"io/fs"
 	"log"
+	mrand "math/rand"
 	"os"
 	"os/exec"
 	"path"
@@ -37,7 +38,7 @@ import (
 	"time"
 
 	"github.com/google/uuid"
-	"go.cypherpunks.su/recfile/v2"
+	"go.cypherpunks.su/recfile/v3"
 	"go.cypherpunks.su/tai64n/v4"
 	"golang.org/x/sys/unix"
 )
@@ -228,7 +229,7 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 		LockAgain:
 			if err = unix.FcntlFlock(fdLock.Fd(), unix.F_SETLKW, &flock); err != nil {
 				if errors.Is(err, unix.EDEADLK) || errors.Is(err, unix.EINTR) {
-					time.Sleep(10 * time.Millisecond)
+					time.Sleep(time.Duration(1+mrand.Intn(20)) * time.Millisecond)
 					goto LockAgain
 				}
 				log.Fatalln(err, fdLock.Name())
@@ -374,7 +375,7 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 	// Prepare command line
 	var cmdName string
 	var args []string
-	if err = unix.Access(doFile.rel, unix.X_OK); err == nil {
+	if err = unix.Access(doFile.a, unix.X_OK); err == nil {
 		cmdName = doFile.a
 		args = make([]string, 0, 3)
 	} else {
@@ -525,38 +526,38 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 					os.FileMode(0o666),
 				); err == nil {
 					fields := []recfile.Field{
-						{Name: "Build", Value: BuildUUID.String()},
-						{Name: "PPID", Value: strconv.Itoa(os.Getpid())},
-						{Name: "Cwd", Value: cwd},
+						{F: "Build", V: BuildUUID.String()},
+						{F: "PPID", V: strconv.Itoa(os.Getpid())},
+						{F: "Cwd", V: cwd},
 					}
 					if cmd.Process != nil {
 						fields = append(fields, recfile.Field{
-							Name: "PID", Value: strconv.Itoa(cmd.Process.Pid),
+							F: "PID", V: strconv.Itoa(cmd.Process.Pid),
 						})
 					}
 					var ts tai64n.TAI64N
 					ts.FromTime(started)
 					fields = append(fields,
-						recfile.Field{Name: "Started", Value: ts.Encode()},
+						recfile.Field{F: "Started", V: ts.Encode()},
 					)
 					ts.FromTime(finished)
 					fields = append(fields,
-						recfile.Field{Name: "Finished", Value: ts.Encode()})
+						recfile.Field{F: "Finished", V: ts.Encode()})
 					fields = append(fields, recfile.Field{
-						Name:  "Duration",
-						Value: strconv.FormatInt(finished.Sub(started).Nanoseconds(), 10),
+						F: "Duration",
+						V: strconv.FormatInt(finished.Sub(started).Nanoseconds(), 10),
 					})
-					fields = append(fields, recfile.Field{Name: "Cmd", Value: cmdName})
+					fields = append(fields, recfile.Field{F: "Cmd", V: cmdName})
 					for _, arg := range args {
-						fields = append(fields, recfile.Field{Name: "Arg", Value: arg})
+						fields = append(fields, recfile.Field{F: "Arg", V: arg})
 					}
 					for _, env := range cmd.Env {
-						fields = append(fields, recfile.Field{Name: "Env", Value: env})
+						fields = append(fields, recfile.Field{F: "Env", V: env})
 					}
 					if exitErr != nil {
 						fields = append(fields, recfile.Field{
-							Name:  "ExitCode",
-							Value: strconv.Itoa(exitErr.ProcessState.ExitCode()),
+							F: "ExitCode",
+							V: strconv.Itoa(exitErr.ProcessState.ExitCode()),
 						})
 					}
 
@@ -570,8 +571,8 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 						}
 						for _, ifchange := range ifchanges {
 							fields = append(fields, recfile.Field{
-								Name:  "Ifchange",
-								Value: ifchange,
+								F: "Ifchange",
+								V: ifchange,
 							})
 						}
 					}
