@@ -1,5 +1,5 @@
 // goredo -- djb's redo implementation on pure Go
-// Copyright (C) 2020-2024 Sergey Matveev <stargrave@stargrave.org>
+// Copyright (C) 2020-2025 Sergey Matveev <stargrave@stargrave.org>
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ func tempfile(dir, prefix string) (*os.File, error) {
 	if err != nil {
 		return nil, err
 	}
-	err = os.Chmod(tmp.Name(), os.FileMode(0666&^UmaskCur))
+	err = os.Chmod(tmp.Name(), os.FileMode(0o666&^UmaskCur))
 	if err != nil {
 		tmp.Close()
 		return nil, err
