@@ -1,8 +1,8 @@
 package main
 
 import (
-	"errors"
 	"io"
+	"io/fs"
 	"os"
 	"path"
 )
@@ -51,7 +51,7 @@ func whichdo(tgt *Tgt) (dos []string, err error) {
 		}
 	}
 	if doFile == "" {
-		err = errors.New("no .do found")
+		err = fs.ErrNotExist
 		return
 	}
 	p := make([]string, 0, upLevels+2)
